==> aliyun-python-sdk-domain-3.13.0.tar.gz: aliyun-python-sdk-domain-3.13.0/aliyunsdkdomain/request/v20180129/CheckDomainRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class CheckDomainRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'CheckDomain')

	def get_FeeCurrency(self):
		return self.get_query_params().get('FeeCurrency')

	def set_FeeCurrency(self,FeeCurrency):
		self.add_query_param('FeeCurrency',FeeCurrency)

	def get_FeePeriod(self):
		return self.get_query_params().get('FeePeriod')

	def set_FeePeriod(self,FeePeriod):
		self.add_query_param('FeePeriod',FeePeriod)

	def get_DomainName(self):
		return self.get_query_params().get('DomainName')

	def set_DomainName(self,DomainName):
		self.add_query_param('DomainName',DomainName)

	def get_FeeCommand(self):
		return self.get_query_params().get('FeeCommand')

	def set_FeeCommand(self,FeeCommand):
		self.add_query_param('FeeCommand',FeeCommand)

	def get_Lang(self):
		return self.get_query_params().get('Lang')

	def set_Lang(self,Lang):
		self.add_query_param('Lang',Lang)

==> aliyun-python-sdk-domain-3.14.3.tar.gz: aliyun-python-sdk-domain-3.14.3/aliyunsdkdomain/request/v20180129/CheckDomainRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdomain.endpoint import endpoint_data

class CheckDomainRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'CheckDomain','domain')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_DomainName(self):
		return self.get_query_params().get('DomainName')

	def set_DomainName(self,DomainName):
		self.add_query_param('DomainName',DomainName)

	def get_FeeCurrency(self):
		return self.get_query_params().get('FeeCurrency')

	def set_FeeCurrency(self,FeeCurrency):
		self.add_query_param('FeeCurrency',FeeCurrency)

	def get_FeePeriod(self):
		return self.get_query_params().get('FeePeriod')

	def set_FeePeriod(self,FeePeriod):
		self.add_query_param('FeePeriod',FeePeriod)

	def get_FeeCommand(self):
		return self.get_query_params().get('FeeCommand')

	def set_FeeCommand(self,FeeCommand):
		self.add_query_param('FeeCommand',FeeCommand)

	def get_Lang(self):
		return self.get_query_params().get('Lang')

	def set_Lang(self,Lang):
		self.add_query_param('Lang',Lang)
